==> gc_board_0.08.06.tar.gz: gc_board_0.08.06/admin/basic_config.php <==
<?
///////////////////////////////////////////////////////////////////////////
// basic_config.php
// ⺻ ȯ 
// 2004. 6. 23.
///////////////////////////////////////////////////////////////////////////

//  mysql ƴ ٸ DB   Ʒ ҽ ߿ mode db
//	κ ľ Ѵ.

///////////////////////////////////////////////////////////////////////////
//  ø   
//
// basic_config.htm Ų ۼϽ    ̸ ø 
// ֽʽÿ.
//
// form   ±׵
// ========================================================================
// name			: value				: 
// ========================================================================
// con_host		: <#DBȣƮ>		: DB ῡ ϴ HOST ̸
// con_user		: <#DB>		: DB ῡ ϴ  ID
// con_passwd	: <#DBн>		: DB ῡ ϴ  н
// con_db		: <#DB̸>			: gc_board table ġ Database
//
// name				: value					: 
// ========================================================================
// new_admin_skin	: <#Ų>	:    Ų ִ 丮
//										 	(⺻ : ../admin/default)
// new_main_skin	: <#Ų>	:    Ų ִ 丮
//											(⺻ : ../main/default)
// new_member_skin	: <#Ų>	:    Ų ִ 丮
//											(⺻ : ../member/default)
// ========================================================================
//
//  Ų  ±׿ տ new ̴  gc_lib.php  ⺻
//	о Ų ϱ ؼ ̴.
//
// Ÿ
// ========================================================================
// <#DB>	: DB   (ũ)
// <#Ų>	: Ų   (ũ)
// ========================================================================
///////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////
// ⺻ ʿ  
///////////////////////////////////////////////////////////////////////////
require_once "../include/gc_manage_lib.php";

///////////////////////////////////////////////////////////////////////////
// ⺻ ʿ  Ȯ
//
// mode			: ⺻  ܿ  Ư ó ʿ ˷ִ 
///////////////////////////////////////////////////////////////////////////
if (!isset($mode))
	$mode = "";

///////////////////////////////////////////////////////////////////////////
//     Ȯ
///////////////////////////////////////////////////////////////////////////
chk_admin();


// Ÿ  ////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////
// mode  db(DB  )  ó
///////////////////////////////////////////////////////////////////////////
if ($mode == "db")
{
	// ̸   غ.
	//  ȵ  ο   .
	if (!($new_connect = @mysql_connect($con_host, $con_user, $con_passwd)))
	{
		out_error("DBῡ ߽ϴ.<br>"
			."ο    ϴ."
			, "../admin/basic_config.php");
	}
	if (!(@mysql_select_db($con_db)))
	{
		out_error("DBῡ ߽ϴ.<br>"
			."ο    ϴ."
			, "../admin/basic_config.php");
	}
	mysql_close($new_connect);

	// ο  
	$save_db_info = "<?php ".$con_host." ".$con_user." ".$con_passwd." ".$con_db." ?>";

	if (!($fp = fopen("../config/db_info.php", "w")))
	{
		out_error("  ۼ ߽ϴ.<br>"
			."gc_board/config丮 㰡 0777 Ͽ ֽʽÿ."
			, "../admin/basic_config.php");
	}
	fwrite($fp, $out_info);
	fclose($fp);
}

///////////////////////////////////////////////////////////////////////////
// mode  skin(Ų  )  ó
///////////////////////////////////////////////////////////////////////////
else if ($mode == "skin")
{
	// Ų 丮  ִ  Ȯ
	if (empty($new_admin_skin) || !file_exists($new_admin_skin))
		out_error($new_admin_skin." 丮 ã Ͽϴ."
			, "../admin/basic_config.php");
	if (empty($new_member_skin) || !file_exists($new_member_skin))
		out_error($new_member_skin." 丮 ã Ͽϴ."
			, "../admin/basic_config.php");
	if (empty($new_main_skin) || !file_exists($new_main_skin))
		out_error($new_main_skin." 丮 ã Ͽϴ."
			, "../admin/basic_config.php");

	// ο  
	$new_skin_query = "update gc_basic_config set admin_skin='$admin_skin'"
				.", member_skin='$member_skin', main_skin='$main_skin'";
	gc_query($new_skin_query);

	// ο Ų ϱ  ΰħ
	echo "<meta http-equiv=\"refresh\" content=\"2;URL=basic_config.php\">\n";
	echo "<br><br><strong><font size=\"3\" color=\"#666666\">"
		."ο Ų մϴ.</font></strong>\n";
	exit;
}


//    ///////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////
// Ų  о
///////////////////////////////////////////////////////////////////////////
$config_view = loadfile($admin_skin."/basic_config.htm");

///////////////////////////////////////////////////////////////////////////
// DB  о  κ
///////////////////////////////////////////////////////////////////////////
$db_info_str = loadfile("../config/db_info.php");

$db_info = explode(" ", $db_info_str);
$out_con_host	= $db_info[1];
$out_con_user	= $db_info[2];
$out_con_passwd	= $db_info[3];
$out_con_db		= $db_info[4];

///////////////////////////////////////////////////////////////////////////
// Ų  о  κ
//
// gc_lib.php  о  ״ ϱ  ʿ.
///////////////////////////////////////////////////////////////////////////


//  κ //////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////
//  DB  
///////////////////////////////////////////////////////////////////////////
$config_view = str_replace("<#DBȣƮ>", $out_con_host, $config_view);
$config_view = str_replace("<#DB>", $out_con_user, $config_view);
$config_view = str_replace("<#DBн>", $out_con_passwd, $config_view);
$config_view = str_replace("<#DB̸>", $out_con_db, $config_view);

///////////////////////////////////////////////////////////////////////////
//  Ų  
///////////////////////////////////////////////////////////////////////////
$config_view = str_replace("<#Ų>", $admin_skin
		, $config_view);
$config_view = str_replace("<#Ų>", $member_skin
		, $config_view);
$config_view = str_replace("<#Ų>", $main_skin
		, $config_view);

///////////////////////////////////////////////////////////////////////////
// DB    
///////////////////////////////////////////////////////////////////////////
$config_view = str_replace("<#DB>", "basic_config.php?mode=db"
		, $config_view);

///////////////////////////////////////////////////////////////////////////
// Ų    
///////////////////////////////////////////////////////////////////////////
$config_view = str_replace("<#Ų>", "basic_config.php?mode=skin"
		, $config_view);

///////////////////////////////////////////////////////////////////////////
// ü (δ ⼭  ȴ.)
///////////////////////////////////////////////////////////////////////////
print_all($admin_top_file, $admin_bottom_file, $config_view);
?>

==> gc_board_0.09.01.tar.gz: gc_board_0.09.01/admin/basic_config.php <==
<?
///////////////////////////////////////////////////////////////////////////
// basic_config.php
// ⺻ ȯ 
// 2005. 6. 6.
///////////////////////////////////////////////////////////////////////////

//  mysql ƴ ٸ DB   Ʒ ҽ ߿ mode db
//	κ ľ Ѵ.

///////////////////////////////////////////////////////////////////////////
//  ø   
//
// basic_config.htm Ų ۼϽ    ̸ ø 
// ֽʽÿ.
//
// form   ±׵
// ========================================================================
// name			: value				: 
// ========================================================================
// con_host		: <#DBȣƮ>		: DB ῡ ϴ HOST ̸
// con_user		: <#DB>		: DB ῡ ϴ  ID
// con_passwd	: <#DBн>		: DB ῡ ϴ  н
// con_db		: <#DB̸>			: gc_board table ġ Database
//
// name				: value					: 
// ========================================================================
// new_admin_skin	: <#Ų>	:    Ų ִ 丮
//										 	(⺻ : ../admin/default)
// new_main_skin	: <#Ų>	:    Ų ִ 丮
//											(⺻ : ../main/default)
// new_member_skin	: <#Ų>	:    Ų ִ 丮
//											(⺻ : ../member/default)
// ========================================================================
//
//  Ų  ±׿ տ new ̴  gc_lib.php  ⺻
//	о Ų ϱ ؼ ̴.
//
// Ÿ
// ========================================================================
// <#DB>	: DB   (ũ)
// <#Ų>	: Ų   (ũ)
// ========================================================================
///////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////
// ⺻ ʿ  
///////////////////////////////////////////////////////////////////////////
require_once "../include/gc_manage_lib.php";

///////////////////////////////////////////////////////////////////////////
// ⺻ ʿ  Ȯ
//
// mode			: ⺻  ܿ  Ư ó ʿ ˷ִ 
///////////////////////////////////////////////////////////////////////////
if (!isset($mode))
	$mode = "";

///////////////////////////////////////////////////////////////////////////
//     Ȯ
///////////////////////////////////////////////////////////////////////////
chk_admin();


// Ÿ  ////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////
// mode  db(DB  )  ó
///////////////////////////////////////////////////////////////////////////
if ($mode == "db")
{
	// ̸   غ.
	//  ȵ  ο   .
	if (!($new_connect = @mysql_connect($con_host, $con_user, $con_passwd)))
	{
		out_error("DBῡ ߽ϴ.<br>"
			."ο    ϴ."
			, "../admin/basic_config.php");
	}
	if (!(@mysql_select_db($con_db)))
	{
		out_error("DBῡ ߽ϴ.<br>"
			."ο    ϴ."
			, "../admin/basic_config.php");
	}
	mysql_close($new_connect);

	// ο  
	$save_db_info = "<?php ".$con_host." ".$con_user." ".$con_passwd." ".$con_db." ?>";

	if (!($fp = fopen("../config/db_info.php", "w")))
	{
		out_error("  ۼ ߽ϴ.<br>"
			."gc_board/config丮 㰡 0777 Ͽ ֽʽÿ."
			, "../admin/basic_config.php");
	}
	fwrite($fp, $out_info);
	fclose($fp);
}

///////////////////////////////////////////////////////////////////////////
// mode  skin(Ų  )  ó
///////////////////////////////////////////////////////////////////////////
else if ($mode == "skin")
{
	// Ų 丮  ִ  Ȯ
	if (empty($new_admin_skin) || !file_exists($new_admin_skin))
		out_error($new_admin_skin." 丮 ã Ͽϴ."
			, "../admin/basic_config.php");
	if (empty($new_member_skin) || !file_exists($new_member_skin))
		out_error($new_member_skin." 丮 ã Ͽϴ."
			, "../admin/basic_config.php");
	if (empty($new_main_skin) || !file_exists($new_main_skin))
		out_error($new_main_skin." 丮 ã Ͽϴ."
			, "../admin/basic_config.php");

	// ο  
	$new_skin_query = "update gc_basic_config set admin_skin='$new_admin_skin'"
				.", member_skin='$new_member_skin', main_skin='$new_main_skin'";
	gc_query($new_skin_query);

	// ο Ų ϱ  ΰħ
	echo "<meta http-equiv=\"refresh\" content=\"2;URL=basic_config.php\">\n";
	echo "<br><br><strong><font size=\"3\" color=\"#666666\">"
		."ο Ų մϴ.</font></strong>\n";
	exit;
}


//    ///////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////
// Ų  о
///////////////////////////////////////////////////////////////////////////
$config_view = loadfile($admin_skin."/basic_config.htm");

///////////////////////////////////////////////////////////////////////////
// DB  о  κ
///////////////////////////////////////////////////////////////////////////
$db_info_str = loadfile("../config/db_info.php");

$db_info = explode(" ", $db_info_str);
$out_con_host	= $db_info[1];
$out_con_user	= $db_info[2];
$out_con_passwd	= $db_info[3];
$out_con_db		= $db_info[4];

///////////////////////////////////////////////////////////////////////////
// Ų  о  κ
//
// gc_lib.php  о  ״ ϱ  ʿ.
///////////////////////////////////////////////////////////////////////////


//  κ //////////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////////////////////
//  DB  
///////////////////////////////////////////////////////////////////////////
$config_view = str_replace("<#DBȣƮ>", $out_con_host, $config_view);
$config_view = str_replace("<#DB>", $out_con_user, $config_view);
$config_view = str_replace("<#DBн>", $out_con_passwd, $config_view);
$config_view = str_replace("<#DB̸>", $out_con_db, $config_view);

///////////////////////////////////////////////////////////////////////////
//  Ų  
///////////////////////////////////////////////////////////////////////////
$config_view = str_replace("<#Ų>", $admin_skin
		, $config_view);
$config_view = str_replace("<#Ų>", $member_skin
		, $config_view);
$config_view = str_replace("<#Ų>", $main_skin
		, $config_view);

///////////////////////////////////////////////////////////////////////////
// DB    
///////////////////////////////////////////////////////////////////////////
$config_view = str_replace("<#DB>", "basic_config.php?mode=db"
		, $config_view);

///////////////////////////////////////////////////////////////////////////
// Ų    
///////////////////////////////////////////////////////////////////////////
$config_view = str_replace("<#Ų>", "basic_config.php?mode=skin"
		, $config_view);

///////////////////////////////////////////////////////////////////////////
// ü (δ ⼭  ȴ.)
///////////////////////////////////////////////////////////////////////////
print_all($admin_top_file, $admin_bottom_file, $config_view);
?>
